betty.gramps.error - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.gramps.error

    """
    Provide Gramps error handling utilities.
    """

    from betty.error import UserFacingError

    class GrampsError(Exception):
        """
        A Gramps API error.
        """

        pass  # pragma: no cover

    class UserFacingGrampsError(GrampsError, UserFacingError):
        """
        A user-facing Gramps API error.
        """

        pass  # pragma: no cover